@@ -9,12 +9,19 @@
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
- *
- * RCS: @(#) $Id: pkge.c,v 1.10 2007/12/13 15:28:43 dgp Exp $
  */
 
+#undef STATIC_BUILD
 #include "tcl.h"
 
+/*
+ * TCL_STORAGE_CLASS is set unconditionally to DLLEXPORT because the
+ * Pkge_Init declaration is in the source file itself, which is only
+ * accessed when we are building a library.
+ */
+#undef TCL_STORAGE_CLASS
+#define TCL_STORAGE_CLASS DLLEXPORT
+
 
 /*
  *----------------------------------------------------------------------
@@ -33,12 +40,12 @@
  *----------------------------------------------------------------------
  */
 
-int
+EXTERN int
 Pkge_Init(
     Tcl_Interp *interp)		/* Interpreter in which the package is to be
 				 * made available. */
 {
-    static char script[] = "if 44 {open non_existent}";
+    static const char script[] = "if 44 {open non_existent}";
 
     if (Tcl_InitStubs(interp, TCL_VERSION, 0) == NULL) {
 	return TCL_ERROR;
